/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.fleet.implement;

import javax.swing.JSpinner;
import javax.swing.SpinnerNumberModel;
import nl.cloudfarming.client.fleet.machine.windows.MachineOverviewPanel;
import nl.cloudfarming.client.fleet.model.Implement;
import nl.cloudfarming.client.util.swing.FormRow;
import org.jdesktop.beansbinding.AutoBinding;
import org.jdesktop.beansbinding.BeanProperty;
import org.jdesktop.beansbinding.BindingGroup;
import org.jdesktop.beansbinding.Bindings;
import org.openide.util.NbBundle;

/**
 * Overview Panel for an implement
 * @author Merijn Zengers <Merijn.Zengers@gmail.nl>
 */
@NbBundle.Messages({"ImplementOverviewPanel workwidth lable text=Work width:"})
public class ImplementOverviewPanel extends MachineOverviewPanel {
    
    private BindingGroup implementBindingGroup = new BindingGroup();
    private BeanProperty fieldPropWorkWidth = BeanProperty.create(Implement.PROP_WORKWIDTH);
    private BeanProperty formPropWorkWidth = BeanProperty.create("value");
    private static final double WORKWIDTH_STEP_SIZE=  0.1;
    private static final double WORKWIDTH_MIN_VALUE = 0.0;
    
    private JSpinner workWidthSpinner;
    
    private Implement implement;
    
    public ImplementOverviewPanel(Implement implement){
        this.implement = implement;
        initComponents();
        bind();
    }
    
    private void initComponents(){
        workWidthSpinner = new JSpinner(new SpinnerNumberModel(WORKWIDTH_MIN_VALUE, WORKWIDTH_MIN_VALUE, Double.MAX_VALUE, WORKWIDTH_STEP_SIZE));
        
        FormRow workWidthRow = new FormRow(false, Bundle.ImplementOverviewPanel_workwidth_lable_text(), Bundle.ImplementOverviewPanel_workwidth_lable_text(), workWidthSpinner);
        add(workWidthRow);
    }
    
    private void bind(){
        implementBindingGroup.addBinding(Bindings.createAutoBinding(AutoBinding.UpdateStrategy.READ_WRITE, implement, fieldPropWorkWidth, workWidthSpinner, formPropWorkWidth));
        implementBindingGroup.bind();
    }

    public JSpinner getWorkWidthSpinner() {
        return workWidthSpinner;
    }
}
